@@ -9,7 +9,7 @@ class BaseBenchmark:
     """Base Benchmark class"""
     def __init__(self, driver):
         self.driver = driver
-        self.logger = logging.getLogger('osb.benchmark')
+        self.logger = logging.getLogger('osb')
         self.params = {}
 
     def set_params(self, **kwargs):
@@ -37,6 +37,8 @@ class UploadBenchmark(BaseBenchmark):
         self.timings = []
         self.objects = []
         self.errors = []
+        self.driver.setup(**self.params)
+
         bucket_name = utils.get_random_name()
         self.storage_class = self.params.get('storage_class')
         self.logger.debug("Creating bucket '%s'", bucket_name)
@@ -59,10 +61,14 @@ class UploadBenchmark(BaseBenchmark):
                         storage_class=self.storage_class,
                         name=name,
                         content=content,
+                        multipart_threshold=self.params['multipart_threshold'],
+                        multipart_chunksize=self.params['multipart_chunksize'],
+                        max_concurrency=self.params['max_concurrency'],
                     )
                     self.timings.append(elapsed)
                     self.objects.append(obj)
                 except driver_errors.DriverConnectionError as err:
+                    self.logger.error(err)
                     self.errors.append(err)
 
 
@@ -77,17 +83,25 @@ class UploadBenchmark(BaseBenchmark):
         size = self.params['object_size']
         total_size = count * size
         test_time = sum(self.timings)
+        rate = (count/test_time) if test_time else 0
+        bw = (total_size/test_time/2**20) if test_time else 0
         stats = {
             'operation': 'upload',
             'ops': count,
             'time': self.total_time,
-            'rate': (count/test_time),
-            'bw': (total_size/test_time/2**20),
+            'bw': bw,
+            'rate': rate,
             'object_size': size,
             'object_number': self.params['object_number'],
+            'multipart_threshold': self.params['multipart_threshold'],
+            'multipart_chunksize': self.params['multipart_chunksize'],
+            'max_concurrency': self.params['max_concurrency'],
             'total_size': total_size,
             'test_time': test_time,
             'errors': error_count,
+            'driver': self.driver.id,
+            'read_timeout': self.driver.read_timeout,
+            'connect_timeout': self.driver.connect_timeout,
         }
         if count > 1:
             stats.update({
@@ -109,9 +123,10 @@ class DownloadBenchmark(BaseBenchmark):
         self.objects = []
         bucket_name = utils.get_random_name()
         self.logger.debug("Creating bucket '%s'", bucket_name)
+        self.storage_class = self.params.get('storage_class')
         self.bucket = self.driver.create_bucket(
             name=bucket_name,
-            storage_class=self.params['storage_class']
+            storage_class=self.storage_class,
         )
         for i in range(self.params['object_number']):
             name = utils.get_random_name()
@@ -121,7 +136,7 @@ class DownloadBenchmark(BaseBenchmark):
             try:
                 obj = self.driver.upload(
                     bucket_id=bucket_name,
-                    storage_class=self.params['storage_class'],
+                    storage_class=self.storage_class,
                     name=name,
                     content=content,
                 )
@@ -158,20 +173,28 @@ class DownloadBenchmark(BaseBenchmark):
         size = self.params['object_size']
         total_size = count * size
         test_time = sum(self.timings)
+        bw = (total_size/test_time/2**20) if test_time else 0
+        rate = (count/test_time) if test_time else 0
         stats = {
             'operation': 'download',
             'ops': count,
             'time': self.total_time,
+            'bw': bw,
+            'rate': rate,
             'object_size': size,
             'object_number': self.params['object_number'],
+            'max_concurrency': 1,
+            'multipart_threshold': 0,
+            'multipart_chunksize': 0,
             'total_size': total_size,
             'test_time': test_time,
             'errors': error_count,
+            'driver': self.driver.id,
+            'read_timeout': self.driver.read_timeout,
+            'connect_timeout': self.driver.connect_timeout,
         }
         if count > 1:
             stats.update({
-                'rate': (count/test_time),
-                'bw': (total_size/test_time/2**20),
                 'avg': statistics.mean(self.timings),
                 'stddev': statistics.stdev(self.timings),
                 'med': statistics.median(self.timings),
